gedidb.CMRDataDownloader
========================

.. currentmodule:: gedidb

.. autoclass:: CMRDataDownloader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CMRDataDownloader.__init__
      ~CMRDataDownloader.download
   
   

   
   
   